@@ -1206,7 +1206,7 @@ return(val)
 generate.dist <- function(fun, n, q, sigma, shape){
 
 	if(fun == "norm"){
-		fun <- rmvnorm
+		fun <- mvtnorm::rmvnorm
 		return(list(fun = fun, n = n, mean = rep(0, q), sigma = sigma))
 	}
 
@@ -1221,7 +1221,7 @@ generate.dist <- function(fun, n, q, sigma, shape){
 	}
 
 	if(fun == "t"){
-		fun <- rmvt
+		fun <- mvtnorm::rmvt
 		return(list(fun = fun, n = n, sigma = sigma, df = shape))
 	}
 
